@@ -30,8 +30,8 @@ import shutil
 import platform
 import gzip
 
-from tpp_tools import *
-from tpp_gui import *
+from pytpp.tpp_tools import *
+from pytpp.tpp_gui import *
 
 
 def run_main():
@@ -39,6 +39,10 @@ def run_main():
     main(*args, **kwargs)
 
 def main(*args, **kwargs):
+    # Check python version
+    if (sys.version_info[0] < 3):
+        print("TRANSIT v3.0+ requires python3.6+. To use with python2, please install TRANSIT version < 3.0")
+        sys.exit(0)
     vars = Globals()
     # Check for arguements
     if not args and not kwargs and hasWx:        
@@ -67,9 +71,9 @@ def main(*args, **kwargs):
             pass
 
     elif not args and not kwargs and not hasWx:
-        print "Please install wxPython to run in GUI Mode."
-        print "To run in Console Mode please follow these instructions:"
-        print ""
+        print("Please install wxPython to run in GUI Mode.")
+        print("To run in Console Mode please follow these instructions:")
+        print("")
         show_help()
 
     else:
@@ -85,7 +89,7 @@ def main(*args, **kwargs):
                            "window-size", "bwa-alg", "replicon-ids","primer-start-window"])
         unknown_flags = set(kwargs.keys()) - known_flags
         if unknown_flags:
-            print "error: unrecognized flags:", ", ".join(unknown_flags)
+            print("error: unrecognized flags:", ", ".join(unknown_flags))
             show_help()
             sys.exit()
 
