@@ -266,7 +266,7 @@ def extract_staggered(infile,outfile,vars):
   if vars.window_size!=-1: message("Looking for start of Tn prefix with P,Q = %d,%d (origin = %d, window size = %d)" % (P,Q,origin,vars.window_size)) # [RJ] Outputting P,Q values and origin/window size
   else: message("Looking for start of Tn prefix within P,Q = [%d,%d]" % (P,Q))
   tot = 0
-  #print infile
+  #print(infile)
   if vars.barseq_catalog_out!=None:
     barcodes_file = vars.base+".barseq" # I could define this in vars
     catalog = open(barcodes_file,"w")
@@ -274,7 +274,7 @@ def extract_staggered(infile,outfile,vars):
     barseq2 = "CGTACGCTGCAGGTCGACGGCCGG"
     barseq1len,barseq2len = len(barseq1),len(barseq2)
   for line in open(infile):
-    #print line
+    #print(line)
     line = line.rstrip()
     if not line: continue
     if line[0]=='>': header = line; continue
@@ -313,7 +313,7 @@ def extract_staggered(infile,outfile,vars):
 
 
 def message(s):
-  #print "[tn_preprocess]",s
+  #print("[tn_preprocess]",s)
   #sys.stdout.flush()
   sys.stderr.write("[tn_preprocess] "+s+"\n")
 
@@ -338,7 +338,7 @@ def select_reads(goodreads,infile,outfile):
       header = line
       id = get_id(line)
     else:
-      if hash.has_key(id):
+      if id in hash:
         output.write(header)
         output.write(line)
   output.close()
@@ -515,11 +515,11 @@ def template_counts(ref,sam,bcfile,vars):
       else:
         pos = i+1
         h = hits[replicon_names[replicon_index]].get(pos,[])
-        f = filter(lambda x: x[0]=='F',h)
-        r = filter(lambda x: x[0]=='R',h)
+        f = list(filter(lambda x: x[0]=='F',h))
+        r = list(filter(lambda x: x[0]=='R',h))
         u = list(set(h))
-        uf = filter(lambda x: x[0]=='F',u)
-        ur = filter(lambda x: x[0]=='R',u)
+        uf = list(filter(lambda x: x[0]=='F',u))
+        ur = list(filter(lambda x: x[0]=='R',u))
         data = [pos,len(f),len(uf),len(r),len(ur),len(f)+len(r),len(uf)+len(ur)]
         sites.append(data)    
     sites_list.append(sites)
@@ -847,10 +847,10 @@ def bwa_subprocess(command, outfile):
     #process.wait()
     (pout,perr) = process.communicate()
     #for line in iter(process.stderr.readline, ''):
-    for line in perr.split('\n'): # returned by communicate()
-        if "Permission denied" in line:
+    for line in perr.split(b'\n'): # returned by communicate()
+        if b"Permission denied" in line:
             raise IOError("Error: BWA encountered a permissions error: \n\n%s" % line)
-        if "invalid option" in line:
+        if b"invalid option" in line:
             raise ValueError("Error: Unrecognized flag for BWA: %s" % (line.split()[-1]))
         sys.stderr.write("%s\n" % line.strip())
 
@@ -935,7 +935,7 @@ def get_read_length(filename):
    i = 0
    for line in fil:
       if i == 1:
-         #print "reads1 line: " + line
+         #print("reads1 line: " + line)
          return len(line.strip())
       i+=1
 
@@ -1006,9 +1006,9 @@ def create_barseq_catalog(vars, replicon_index):
   goodbc = {}
   for bc,sites2 in mapsto.items(): 
     pop = popularity(sites2) # make a table of locations at which the barcode appears
-    #print bc,pop
+    #print(bc,pop)
     if len(pop)==1: goodbc[bc] = 1
-  #for x in sorted(sites.items()): print x[0],genome[x[0]-1:x[0]+1],popularity(x[1])
+  #for x in sorted(sites.items()): print(x[0],genome[x[0]-1:x[0]+1],popularity(x[1]))
 
   file = open(vars.barseq_catalog_out[replicon_index],"w")  
   file.write("# Barseq (stats are at the bottom): reads = %s, ref = %s\n" % (vars.fq1,vars.ref))
@@ -1070,7 +1070,7 @@ def generate_output(vars):
     cur_tc = sum(cur_tcounts)
     cur_ratio = cur_rc/float(cur_tc) if (cur_rc != 0 and cur_tc !=0) else 0
     cur_ta_sites = len(cur_rcounts)
-    cur_tas_hit = len(filter(lambda x: x>0,cur_rcounts))
+    cur_tas_hit = len(list(filter(lambda x: x>0,cur_rcounts)))
     cur_density = cur_tas_hit/float(cur_ta_sites) if cur_tas_hit != 0 else 0
     counts[replicon_index].sort(key=lambda x: x[-1])
     cur_max_tc = counts[replicon_index][-1][6]
@@ -1202,17 +1202,17 @@ def generate_output(vars):
   infile = open(vars.stats)
   for line in infile:
       if '#' in line:
-          print line.rstrip()
+          print(line.rstrip())
   infile.close()
 
 #############################################################################
 
 def error(s):
-  print "error:",s
+  print("error:",s)
   sys.exit(0)
 
 def warning(s):
-  print "warning:",s
+  print("warning:",s)
 
 
 
@@ -1308,7 +1308,7 @@ def verify_inputs(vars):
         error('cannot find BWA executable. Please include the full executable name as well as its directory.')
 
 def initialize_globals(vars, args=[], kwargs={}):
-    vars.fq1,vars.fq2,vars.ref,vars.bwa,vars.bwa_alg,vars.replicon_ids,vars.base,vars.maxreads = "","","","","","","",""
+    vars.fq1,vars.fq2,vars.ref,vars.bwa,vars.bwa_alg,vars.replicon_ids,vars.base,vars.maxreads = "","","","","","","",-1
     vars.mm1 = 1 # mismatches allowed in Tn prefix AND adapter prefix on read2
     vars.transposon = 'Himar1'
     vars.protocol = "Sassetti"
@@ -1433,20 +1433,21 @@ def save_config(vars):
   f.close()
 
 def show_help():
-  #print 'usage: python PATH/src/tpp.py -bwa <EXECUTABLE_WITH_PATH> -ref <fasta-file|comma_separated_list> -reads1 <FASTQ_OR_FASTA_FILE> [-reads2 <FASTQ_OR_FASTA_FILE>] -output <BASE_FILENAME> [-maxreads <N>] [-mismatches <N>] [-flags "<STRING>"] [-tn5|-himar1] [-primer <seq>] [-primer-start-window INT,INT] [-window-size INT] [-barseq_catalog_in|_out <file>] [-replicon-ids <comma_separated_list_of_names>]'
+  #print('usage: python PATH/src/tpp.py -bwa <EXECUTABLE_WITH_PATH> -ref <fasta-file|comma_separated_list> -reads1 <FASTQ_OR_FASTA_FILE> [-reads2 <FASTQ_OR_FASTA_FILE>] -output <BASE_FILENAME> [-maxreads <N>] [-mismatches <N>] [-flags "<STRING>"] [-tn5|-himar1] [-primer <seq>] [-primer-start-window INT,INT] [-window-size INT] [-barseq_catalog_in|_out <file>] [-replicon-ids <comma_separated_list_of_names>]')
 
-  print 'usage: python PATH/src/tpp.py -bwa <EXECUTABLE_WITH_PATH> -ref <fasta-file|comma_separated_list> -reads1 <FASTQ_OR_FASTA_FILE> [-reads2 <FASTQ_OR_FASTA_FILE>] -output <BASE_FILENAME> [OPTIONAL ARGS]'
-  print '  OPTIONAL ARGS:'
-  print '    -protocol [Sassetti|Tn5|Mme1] # which sample prep protocol was used?; sassetti protocol is the default; this sets the default transposon and primer sequence'
-  print '    -primer <seq>      # prefix of reads corresponding to end of transposon at junction with genomic sequence; can override default seq' 
-  print '    -maxreads <INT>'
-  print '    -mismatches <INT>  # when searching for constant regions in reads 1 and 2; default is 1'
-  print '    -flags "<STRING>"  # args to pass to BWA'
-  print '    -primer-start-window INT,INT # position in read to search for start of primer; default is [0,20]'
-  print '    -window-size INT   # automatic method to set window'
-  print '    -barseq_catalog_in|-barseq_catalog_out <file>'
-  print '    -replicon-ids <comma_separated_list_of_names> # if multiple replicons/genomes/contigs/sequences were provided in -ref, give them names.'
-  print '                                                  # Enter \'auto\' for autogenerated ids.'
+  print('usage: python PATH/src/tpp.py -bwa <EXECUTABLE_WITH_PATH> -ref <fasta-file|comma_separated_list> -reads1 <FASTQ_OR_FASTA_FILE> [-reads2 <FASTQ_OR_FASTA_FILE>] -output <BASE_FILENAME> [OPTIONAL ARGS]')
+  print('  OPTIONAL ARGS:')
+  print('    -protocol [Sassetti|Tn5|Mme1] # which sample prep protocol was used?; sassetti protocol is the default; this sets the default transposon and primer sequence')
+  print('    -primer <seq>      # prefix of reads corresponding to end of transposon at junction with genomic sequence; can override default seq' )
+  print('    -maxreads <INT>')
+  print('    -mismatches <INT>  # when searching for constant regions in reads 1 and 2; default is 1')
+  print('    -flags "<STRING>"  # args to pass to BWA')
+  print('    -bwa-alg [aln|mem]  # Default: mem. Algorithm to use for mapping reads with bwa' )
+  print('    -primer-start-window INT,INT # position in read to search for start of primer; default is [0,20]')
+  print('    -window-size INT   # automatic method to set window')
+  print('    -barseq_catalog_in|-barseq_catalog_out <file>')
+  print('    -replicon-ids <comma_separated_list_of_names> # if multiple replicons/genomes/contigs/sequences were provided in -ref, give them names.')
+  print('                                                  # Enter \'auto\' for autogenerated ids.')
 
 class Globals:
   pass
