@@ -580,10 +580,19 @@ class GIMethod(base.QuadConditionMethod):
 
         (args, kwargs) = transit_tools.cleanargs(rawargs)
 
+        # ctrl-vs-exp = condition 1-vs-2
+        # originally, MAD defined order of CL args this way: strA/cond1, strB/cond1, strA/cond2, strB/cond
+        #ctrldataA = args[0].split(",")
+        #ctrldataB = args[1].split(",")
+        #expdataA = args[2].split(",")
+        #expdataB = args[3].split(",")
+
+        # TRI changed order of args this way: strA/cond1, strA/cond2, strB/cond1, strB/cond
         ctrldataA = args[0].split(",")
-        ctrldataB = args[1].split(",")
-        expdataA = args[2].split(",")
+        expdataA = args[1].split(",")
+        ctrldataB = args[2].split(",")
         expdataB = args[3].split(",")
+
         annotationPath = args[4]
         output_path = args[5]
         output_file = open(output_path, "w")
@@ -633,7 +642,6 @@ class GIMethod(base.QuadConditionMethod):
         Na2 = len(self.expdataA)
         Nb2 = len(self.expdataB)
 
-
         # Get data
         self.transit_message("Getting Data")
         (data, position) = transit_tools.get_validated_data(wiglist, wxobj=self.wxobj)
@@ -893,7 +901,13 @@ class GIMethod(base.QuadConditionMethod):
 
     @classmethod
     def usage_string(self):
-        return """python %s GI <comma-separated .wig control files condition A> <comma-separated .wig control files condition B> <comma-separated .wig experimental files condition A> <comma-separated .wig experimental files condition B> <annotation .prot_table or GFF3> <output file> [Optional Arguments]
+        #return """python %s GI <comma-separated .wig control files condition A> <comma-separated .wig control files condition B> <comma-separated .wig experimental files condition A> <comma-separated .wig experimental files condition B> <annotation .prot_table or GFF3> <output file> [Optional Arguments]
+        return """python %s GI <wigs_for_strA_cond1> <wigs_for_strA_cond2> <wigs_for_strB_cond1> <wigs_for_strB_cond2> <annotation .prot_table or GFF3> <output file> [Optional Arguments]
+
+        GI performs a comparison among 4 groups of datasets, strain A and B assessed in conditions 1 and 2 (e.g. control vs treatment).
+        It looks for interactions where the response to the treatment (i.e. effect on insertion counts) depends on the strain (output variable: delta_LFC).
+        Provide replicates in each group as a comma-separated list of wig files.
+        Significant interactions are those with "HDI outside ROPE?"=TRUE, and all genes are sorted by significance using BFDR."
 
         Optional Arguments:
         -s <integer>    :=  Number of samples. Default: -s 10000
