@@ -23,7 +23,7 @@ import numpy
 import scipy.stats
 import datetime
 
-import base
+from pytransit.analysis import base
 import pytransit.transit_tools as transit_tools
 import pytransit.tnseq_tools as tnseq_tools
 import pytransit.norm_tools as norm_tools
@@ -73,7 +73,7 @@ class HMMSitesFile(base.TransitFile):
             elif tmp[col] == "GD": gd+=1
             elif tmp[col] == "NE": ne+=1
             elif tmp[col] == "GA": ga+=1
-            else: print tmp
+            else: print(tmp)
             T+=1
 
         text = """Results:
@@ -356,7 +356,7 @@ class HMMMethod(base.SingleConditionMethod):
         #################
 
         T = len(O); total=0; state2count = dict.fromkeys(range(Nstates),0)
-        for t in xrange(T):
+        for t in range(T):
             state = Q_opt[t]
             state2count[state] +=1
             total+=1
@@ -395,7 +395,7 @@ class HMMMethod(base.SingleConditionMethod):
 
         states = [int(Q_opt[t]) for t in range(T)]
         last_orf = ""
-        for t in xrange(T):
+        for t in range(T):
             s_lab = label.get(states[t], "Unknown State")
             gamma_t = (alpha[:,t] * beta[:,t])/numpy.sum(alpha[:,t] * beta[:,t])
             genes_at_site = hash.get(position[t], [""])
@@ -452,7 +452,7 @@ class HMMMethod(base.SingleConditionMethod):
         C[0] = 1.0/numpy.sum(alpha[:,0])
         alpha[:,0] = C[0] * alpha[:,0]
 
-        for t in xrange(1, T):
+        for t in range(1, T):
             #B[i](O[:,t])  =>  numpy.prod(B[i](O[:,t]))
             #b_o = numpy.array([numpy.prod(B[i](O[:,t])) for i in range(N)])
             b_o = [B[i](O[t]) for i in range(N)]
@@ -468,7 +468,7 @@ class HMMMethod(base.SingleConditionMethod):
             text = "Running HMM Method... %1.1f%%" % (100.0*self.count/self.maxiterations)
             self.progress_update(text, self.count)
             self.count+=1
-            #print t, O[:,t], alpha[:,t]
+            #print(t, O[:,t], alpha[:,t])
 
         log_Prob_Obs = - (numpy.sum(numpy.log(C)))
         return(( log_Prob_Obs, alpha, C ))
@@ -482,7 +482,7 @@ class HMMMethod(base.SingleConditionMethod):
         beta[:,T-1] = 1.0
         if C.any(): beta[:,T-1] = beta[:,T-1] * C[T-1]
 
-        for t in xrange(T-2, -1, -1):
+        for t in range(T-2, -1, -1):
             #B[i](O[:,t])  =>  numpy.prod(B[i](O[:,t]))
             #b_o = numpy.array([numpy.prod(B[i](O[:,t])) for i in range(N)])
             b_o = [B[i](O[t]) for i in range(N)]
@@ -514,7 +514,7 @@ class HMMMethod(base.SingleConditionMethod):
         Q = numpy.zeros((N, T), dtype=int)
 
         numpy.seterr(divide='ignore')
-        for t in xrange(1, T):
+        for t in range(1, T):
             b_o = [B[i](O[t]) for i in range(N)]
             #nus = delta[:, t-1] + numpy.log(A)
             nus = delta[:, t-1] + A
@@ -525,7 +525,7 @@ class HMMMethod(base.SingleConditionMethod):
             self.count+=1
 
         Q_opt = [int(numpy.argmax(delta[:,T-1]))]
-        for t in xrange(T-2, -1, -1):
+        for t in range(T-2, -1, -1):
             Q_opt.insert(0, Q[Q_opt[0],t+1])
 
             text = "Running HMM Method... %5.1f%%" % (100.0*self.count/self.maxiterations)
@@ -564,6 +564,8 @@ class HMMMethod(base.SingleConditionMethod):
 
         num2label = {0:"ES", 1:"GD", 2:"NE", 3:"GA"}
         output.write("#HMM - Genes\n")        
+
+        lines,counts = [],{}
         for gene in G:
             
             reads_nz = [c for c in gene.reads.flatten() if c > 0]
@@ -584,10 +586,11 @@ class HMMMethod(base.SingleConditionMethod):
 
 
             if gene.n > 0:
-                E = tnseq_tools.ExpectedRuns(gene.n,   1.0 - theta)
-                V = tnseq_tools.VarR(gene.n,   1.0 - theta)
+                # this was intended to call genes ES if have sufficiently long run, but n0 (#ES) not even consecutive
+                #E = tnseq_tools.ExpectedRuns(gene.n,   1.0 - theta)
+                #V = tnseq_tools.VarR(gene.n,   1.0 - theta)
                 if n0 == gene.n: S = "ES"
-                elif n0 >= int(E+(3*math.sqrt(V))): S = "ES"
+                #elif n0 >= int(E+(3*math.sqrt(V))): S = "ES"
                 else:
                     temp = max([(statedist.get(s, 0), s) for s in [0, 1, 2, 3]])[1]
                     S = num2label[temp]
@@ -595,8 +598,14 @@ class HMMMethod(base.SingleConditionMethod):
                 E = 0.0
                 V = 0.0
                 S = "N/A"
-            output.write("%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%1.4f\t%1.2f\t%s\n" % (gene.orf, gene.name, gene.desc, gene.n, n0, n1, n2, n3, gene.theta(), avg_read_nz, S))
+            lines.append("%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%1.4f\t%1.2f\t%s\n" % (gene.orf, gene.name, gene.desc, gene.n, n0, n1, n2, n3, gene.theta(), avg_read_nz, S))
+            if S not in counts: counts[S] = 0
+            counts[S] += 1
 
+        output.write("#genes: ES=%s, GD=%s, NE=%s, GA=%s, N/A=%s\n" % tuple([counts.get(x,0) for x in "ES GD NE GA N/A".split()]))
+        output.write("#key: ES=essential, GD=insertions cause growth-defect, NE=non-essential, GA=insertions confer growth-advantage, N/A=not analyzed (genes with 0 TA sites)\n")
+        output.write("#ORF\tgene\tannotation\tTAs\tES sites\tGD sites\tNE sites\tGA sites\tsaturation\tmean\tcall\n")
+        for line in lines: output.write(line)
         output.close()
 
 
@@ -616,8 +625,8 @@ if __name__ == "__main__":
     G.console_message("Printing the member variables:")   
     G.print_members()
 
-    print ""
-    print "Running:"
+    print("")
+    print("Running:")
 
     G.Run()
 
